# Sammen

Dansk for together - multiple watch to ensure special events come together or go away. 

[License: MIT](https://git.sr.ht/~sthagen/sammen/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/sammen.svg?style=flat)](https://pypi.python.org/pypi/sammen/)
[![downloads](https://img.shields.io/pypi/dm/sammen.svg?style=flat)](https://pypi.python.org/pypi/sammen/)
[![wheel](https://img.shields.io/pypi/wheel/sammen.svg?style=flat)](https://pypi.python.org/pypi/sammen/)
[![supported-versions](https://img.shields.io/pypi/pyversions/sammen.svg?style=flat)](https://pypi.python.org/pypi/sammen/)
[![supported-implementations](https://img.shields.io/pypi/implementation/sammen.svg?style=flat)](https://pypi.python.org/pypi/sammen/)

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of sammen](https://todo.sr.ht/~sthagen/sammen).

## Primary Source repository

The primary source repository of [sammen is at sourcehut](https://git.sr.ht/~sthagen/sammen)
a collection of tools useful for software development.
